==> dde-control-center_5.5.149.orig.tar.xz: dde-control-center-5.5.149/src/frame/window/modules/systeminfo/systeminfowidget.cpp <==
// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "systeminfowidget.h"
#include "window/utils.h"
#include "window/gsettingwatcher.h"
#include "widgets/multiselectlistview.h"

#include <DStandardItem>

#include <QVBoxLayout>
#include <QStandardItemModel>
#include <QIcon>
#include <QList>
#include <QSettings>
#include <QDebug>
#include <QDir>

DWIDGET_USE_NAMESPACE
using namespace DCC_NAMESPACE::systeminfo;

SystemInfoWidget::SystemInfoWidget(QWidget *parent)
    : QWidget(parent)
    , m_mainContentLayout(new QVBoxLayout(this))
    , m_listView(new dcc::widgets::MultiSelectListView(this))
    , m_itemModel(new QStandardItemModel(this))
{
    initWidget();
    initData();
}

SystemInfoWidget::~SystemInfoWidget()
{

}

void SystemInfoWidget::initWidget()
{
    m_listView->setAccessibleName("List_ systeminfomenulist");
    m_listView->setFrameShape(QFrame::NoFrame);
    m_listView->setEditTriggers(QListView::NoEditTriggers);
    m_listView->setModel(m_itemModel);
    m_listView->setViewportMargins(ScrollAreaMargins);
    m_listView->setIconSize(ListViweIconSize);
    m_listView->setItemSize(ListViweSysItemSize);

    m_mainContentLayout->setMargin(0);
    m_mainContentLayout->addWidget(m_listView);

    setLayout(m_mainContentLayout);
}

void SystemInfoWidget::initData()
{
    m_itemList = {
        {"dcc_on_sel", tr("About This PC"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowAboutNative), nullptr, "aboutThisPc"},
        //~ contents_path /systeminfo/Edition License
        {"dcc_version", tr("Edition License"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowVersionProtocol), nullptr, "editionLicense"},
        //~ contents_path /systeminfo/End User License Agreement
        {"dcc_protocol", tr("End User License Agreement"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowEndUserLicenseAgreement), nullptr, "endUserLicenseAgreement"},
        //~ contents_path /systeminfo/Privacy Policy
        {"dcc_privacy_policy", tr("Privacy Policy"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowPrivacyPolicy), nullptr, "privacyPolicy"}
    };

    for (auto m : m_itemList) {
        DStandardItem *item = new DStandardItem;
        item->setIcon(QIcon::fromTheme(m.itemIcon));
        item->setText(m.itemText);
        item->setData(VListViewItemMargin, Dtk::MarginsRole);
        m_itemModel->appendRow(item);
        GSettingWatcher::instance()->bind(m.gsettingsName, m_listView, item);
    }

   if(InsertPlugin::instance()->updatePluginInfo("systeminfo"))
        InsertPlugin::instance()->pushPlugin(m_itemModel,m_itemList);

    connect(m_listView, &DListView::clicked, this, &SystemInfoWidget::onListClicked);
    connect(m_listView, &DListView::activated, m_listView, &DListView::clicked);
    connect(GSettingWatcher::instance(), &GSettingWatcher::requestUpdateSecondMenu, this, &SystemInfoWidget::onRequestUpdateSecondMenu);
}

DListView *SystemInfoWidget::getSystemListViewPointer()
{
    return m_listView;
}

void SystemInfoWidget::showDefaultWidget()
{
    if (!m_listView)
        return;

    for(int i = 0; i < m_listView->model()->rowCount(); i++) {
        if (!m_listView->isRowHidden(i)) {
            m_listView->activated(m_listView->model()->index(i, 0));
            break;
        }
    }
}

bool SystemInfoWidget::configContent(const QString &configName)
{
    for (auto m : m_itemList) {
        if (configName == m.gsettingsName)
            return true;
    }
    return false;
}

int SystemInfoWidget::showPath(const QString &path)
{
    QString tmpPath = path.split('/').first();
    for (int i = 0; i < m_itemList.size(); ++i) {
        auto menu = m_itemList[i];
        if (tr(tmpPath.toStdString().c_str()) == menu.itemText) {
            setCurrentIndex(i);
            return 0;
        }
    }

    if (tmpPath == "Backup and Restore") {
        setCurrentIndex(m_itemModel->rowCount() - 1);
        return 0;
    }

    return -1;
}

void SystemInfoWidget::setCurrentIndex(int index)
{
    QModelIndex mindex = m_itemModel->index(index, 0);
    m_listView->setCurrentIndex(mindex);
    Q_EMIT m_listView->clicked(mindex);
}

void SystemInfoWidget::onRequestUpdateSecondMenu(int row, const QString & name)
{
    //不是本模块配置不响应
    if (!configContent(name))
        return;
    bool isAllHiden = true;
    for (int i = 0; i < m_itemModel->rowCount(); i++) {
        if (!m_listView->isRowHidden(i))
            isAllHiden = false;
    }

    if (m_listView->selectionModel()->selectedRows().size() > 0) {
        int index = m_listView->selectionModel()->selectedRows()[0].row();
        Q_EMIT requestUpdateSecondMenu(index == row);
    } else {
        Q_EMIT requestUpdateSecondMenu(false);
    }

    if (isAllHiden) {
        m_lastIndex = QModelIndex();
        m_listView->clearSelection();
    }
}

void SystemInfoWidget::onListClicked(const QModelIndex &index)
{
    if (m_lastIndex == index)
    	return;

    m_lastIndex = index;
    m_itemList[index.row()].itemSignal.invoke(m_itemList[index.row()].plugin ? m_itemList[index.row()].plugin : this);
    m_listView->resetStatus(index);
}

==> dde-control-center_5.5.197.orig.tar.xz: dde-control-center-5.5.197/src/frame/window/modules/systeminfo/systeminfowidget.cpp <==
// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "systeminfowidget.h"
#include "window/utils.h"
#include "window/gsettingwatcher.h"
#include "widgets/multiselectlistview.h"

#include <DStandardItem>

#include <QVBoxLayout>
#include <QStandardItemModel>
#include <QIcon>
#include <QList>
#include <QSettings>
#include <QDebug>
#include <QDir>

DWIDGET_USE_NAMESPACE
using namespace DCC_NAMESPACE::systeminfo;

SystemInfoWidget::SystemInfoWidget(QWidget *parent)
    : QWidget(parent)
    , m_mainContentLayout(new QVBoxLayout(this))
    , m_listView(new dcc::widgets::MultiSelectListView(this))
    , m_itemModel(new QStandardItemModel(this))
{
    initWidget();
    initData();
}

SystemInfoWidget::~SystemInfoWidget()
{

}

void SystemInfoWidget::initWidget()
{
    m_listView->setAccessibleName("List_ systeminfomenulist");
    m_listView->setFrameShape(QFrame::NoFrame);
    m_listView->setEditTriggers(QListView::NoEditTriggers);
    m_listView->setModel(m_itemModel);
    m_listView->setViewportMargins(ScrollAreaMargins);
    m_listView->setIconSize(ListViweIconSize);
    m_listView->setItemSize(ListViweSysItemSize);

    m_mainContentLayout->setMargin(0);
    m_mainContentLayout->addWidget(m_listView);

    setLayout(m_mainContentLayout);
}

void SystemInfoWidget::initData()
{
    m_itemList = {
        {"dcc_on_sel", tr("About This PC"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowAboutNative), nullptr, "aboutThisPc"},
        //~ contents_path /systeminfo/Edition License
        {"dcc_version", tr("Edition License"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowVersionProtocol), nullptr, "editionLicense"},
        //~ contents_path /systeminfo/End User License Agreement
        {"dcc_protocol", tr("End User License Agreement"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowEndUserLicenseAgreement), nullptr, "endUserLicenseAgreement"},
        //~ contents_path /systeminfo/Privacy Policy
        {"dcc_privacy_policy", tr("Privacy Policy"), QMetaMethod::fromSignal(&SystemInfoWidget::requestShowPrivacyPolicy), nullptr, "privacyPolicy"}
    };

    for (int i = 0; i < m_itemList.size(); ++i) {
        const auto &m = m_itemList[i];
        DStandardItem *item = new DStandardItem;
        item->setIcon(QIcon::fromTheme(m.itemIcon));
        item->setText(m.itemText);
        item->setData(VListViewItemMargin, Dtk::MarginsRole);
        m_itemModel->appendRow(item);
        GSettingWatcher::instance()->bind(m.gsettingsName, m_listView, item);

        // 服务器版本隐藏版本协议二级菜单
        if (IsServerSystem) {
            if (m.gsettingsName == "editionLicense") {
                m_listView->setRowHidden(i, true);
            }
        }
    }

    if (InsertPlugin::instance()->updatePluginInfo("systeminfo"))
        InsertPlugin::instance()->pushPlugin(m_itemModel, m_itemList);

    connect(m_listView, &DListView::clicked, this, &SystemInfoWidget::onListClicked);
    connect(m_listView, &DListView::activated, m_listView, &DListView::clicked);
    connect(GSettingWatcher::instance(), &GSettingWatcher::requestUpdateSecondMenu, this, &SystemInfoWidget::onRequestUpdateSecondMenu);
    if (IsServerSystem) {
        connect(GSettingWatcher::instance(),
                &GSettingWatcher::requestShowSecondMenu, this, [this](int row) {
                    if (m_itemList[row].gsettingsName == "editionLicense") {
                        m_listView->setRowHidden(row, true);
                    }
                });
    }
}

DListView *SystemInfoWidget::getSystemListViewPointer()
{
    return m_listView;
}

void SystemInfoWidget::showDefaultWidget()
{
    if (!m_listView)
        return;

    for(int i = 0; i < m_listView->model()->rowCount(); i++) {
        if (!m_listView->isRowHidden(i)) {
            m_listView->activated(m_listView->model()->index(i, 0));
            break;
        }
    }
}

bool SystemInfoWidget::configContent(const QString &configName)
{
    for (auto m : m_itemList) {
        if (configName == m.gsettingsName)
            return true;
    }
    return false;
}

int SystemInfoWidget::showPath(const QString &path)
{
    QString tmpPath = path.split('/').first();
    for (int i = 0; i < m_itemList.size(); ++i) {
        auto menu = m_itemList[i];
        if (tr(tmpPath.toStdString().c_str()) == menu.itemText) {
            setCurrentIndex(i);
            return 0;
        }
    }

    if (tmpPath == "Backup and Restore") {
        setCurrentIndex(m_itemModel->rowCount() - 1);
        return 0;
    }

    return -1;
}

void SystemInfoWidget::setCurrentIndex(int index)
{
    QModelIndex mindex = m_itemModel->index(index, 0);
    m_listView->setCurrentIndex(mindex);
    Q_EMIT m_listView->clicked(mindex);
}

void SystemInfoWidget::onRequestUpdateSecondMenu(int row, const QString & name)
{
    //不是本模块配置不响应
    if (!configContent(name))
        return;
    bool isAllHiden = true;
    for (int i = 0; i < m_itemModel->rowCount(); i++) {
        if (!m_listView->isRowHidden(i))
            isAllHiden = false;
    }

    if (m_listView->selectionModel()->selectedRows().size() > 0) {
        int index = m_listView->selectionModel()->selectedRows()[0].row();
        Q_EMIT requestUpdateSecondMenu(index == row);
    } else {
        Q_EMIT requestUpdateSecondMenu(false);
    }

    if (isAllHiden) {
        m_lastIndex = QModelIndex();
        m_listView->clearSelection();
    }
}

void SystemInfoWidget::onListClicked(const QModelIndex &index)
{
    if (m_lastIndex == index)
        return;

    m_lastIndex = index;
    m_itemList[index.row()].itemSignal.invoke(m_itemList[index.row()].plugin ? m_itemList[index.row()].plugin : this);
    m_listView->resetStatus(index);
}
